AddExtension

Struct AddExtension 

pub struct AddExtension<S, T> { /* private fields */ }
Available on crate feature axum only.
Middleware for adding some shareable value to request extensions.

See Passing state from middleware to handlers for more details.